// FILE: circle.c
//
// main routine for circle program
//		Make an object consisting of a flat circle in XY plane
//
// Created by
// Jerry Isdale
// Isdale Engineering
// 4053 Beethoven St.
// Los Angeles, CA, 90066
//
// This code is public domain
//

#include <dir.h>
#include <dos.h>
#include <iegeom.h>

extern int errno;
char *pathname;
char progname[MAXPATH];
char tmpname[MAXPATH];

//-----------------------------------------------
void Usage(void)
{
eprintf("%s\n",pathname);
eprintf( "\
   Creates an object with one circular face\n\
   in X-Y plane, centered on the origin\n\
Usage: %s [-r radius] [-f numFacets] outfile\n",progname);
eprintf( "\
   -r radius\n\
      Radius of circle (Default = 1.0).\n\
   -f facets\n\
      Number of facets (sides) in circle, (Default = 6 sides)\n");
exit(0);
}

//-----------------------------------------------
void main( int argc, char *argv[])
{
   pIeObject oop = NULL;
   char outfile[MAXPATH];
   
   int nfacet = 6;
   float radius = 1.0;

	outfile[0] = NULL;

   pathname = *argv++;
	strlwr(pathname);
	fnsplit(pathname,tmpname,tmpname, progname, tmpname);

	// set error reporting to stdout
	eopenf(NULL);

   argc--;
	if (argc == 0)
		Usage();
	if (strcmp(*argv,"-") == 0)
		Usage();
	while (argc > 0) 
	{
	   if (argv[0][0] == '-') 
			switch (argv[0][1])
			{
	   		case 'r':
			   	if (argv[1] == NULL)
					{
		   			eprintf( "%s: -r missing radius\n",	progname);
						exit(0);
					}
		   		argc--; argv++;
	   			if (sscanf(argv[0],"%f",&radius) != 1)
					{
	   				eprintf( "%s: ERROR Bad -r radius : %s\n", 
							progname,argv[0]);
						exit(0);
					}
	   			argc--; argv++;
					break;
	   	    case 'f':
		   		if (argv[1] == NULL) 
					{
		   			eprintf(  "%s: ERROR no facets given\n", progname);
						exit(0);
					}
		   		argc--; argv++;
	   			if (sscanf(argv[0],"%d",&nfacet) != 1)
					{
	   				eprintf( "%s: ERROR Bad -f facets : %s\n", 
							progname,argv[0]);
						exit(0);
					}
	   			argc--; argv++;
					break;
				default:
					eprintf("%s: Unkown Option %s\n",progname, argv[0]);
					exit(0);
		  }
	   else 
		{
		   strcpy( outfile, argv[0]);
		   argc--; argv++;
	   }
   }

	if (outfile[0] == NULL)
	{
		eprintf("%s: missing output file\n", progname);
		exit(1);
	}
					  
	eprintf( "Output to %s\n", outfile);
	eprintf( "Radius = %g, Num Facets = %d\n",	radius, nfacet);
//-----------------------------------------------

	oop = ieg_Circle( radius, nfacet);
	if (!oop)
	{
		eprintf("%s:Cant make circle \n", progname);
		exit(0);
	}

//-----------------------------------------------
	ieg_WritePLG ( oop, outfile, 1.0, TRUE);
}
